@@ -65,16 +65,16 @@ def clean_opcode(opcode_list):
 
 def collapse_opcode(opcode_list, collapse):
     '''
-    Collapse opcodes by certain level.
+    Collapse opcodes by certain level.  
 
-    input: list of strings, int
-    output: list of strings
+    input: list of strings, int  
+    output: list of strings  
 
-    collapse
-    - 0: Count all opcodes including all the PUSH-like, DUP-like and SWAP-like ones.
-    - 1: Collapse all PUSH-like opcodes to PUSH, DUP-like opcodes to DUP, SWAP-like opcodes to SWAP and LOG-like opcode to LOG.
-    - 2: Drop PUSH-like, DUP-like and SWAP-like opcodes, then replace all LOG-like opcodes with LOG.
-    - 3: Drop all PUSH-like, DUP-like, SWAP-like and LOG-like opcodes.
+    collapse  
+    - 0: Count all opcodes including all the PUSH-like, DUP-like and SWAP-like ones.  
+    - 1: Collapse all PUSH-like opcodes to PUSH, DUP-like opcodes to DUP, SWAP-like opcodes to SWAP and LOG-like opcode to LOG.  
+    - 2: Drop PUSH-like, DUP-like and SWAP-like opcodes, then replace all LOG-like opcodes with LOG.  
+    - 3: Drop all PUSH-like, DUP-like, SWAP-like and LOG-like opcodes.  
     '''
     collapsed_opcode_list = []
 
@@ -254,10 +254,15 @@ def split_bytecode(bytecode):
     deployment_bytecode = bytecode[:runtime_start]
 
     bzzr_start = bytecode.find('a165627a7a72305820') + 18
-    runtime_bytecode = bytecode[runtime_start:bzzr_start]
-    bzzr = 'bzzr: '+bytecode[bzzr_start:bzzr_start+64]
+    if bzzr_start < 18:
+        bzzr_start = len(bytecode)
+        args_start = len(bytecode)
+    else:
+        bzzr = 'bzzr: '+bytecode[bzzr_start:bzzr_start+64]
+        args_start = bzzr_start + 64 + 4
 
-    args_start = bzzr_start+64+4
+    runtime_bytecode = bytecode[runtime_start:bzzr_start]
+    
     for i in range(args_start, len(bytecode), 64):
         aug = str('Arg [{}]: '.format(
             str((i-args_start) // 64))+bytecode[i:i+64])
